function hc=chain(n, m, phi)
% chainx(n,m,phi) linear chain with n members
%   eigenmode m, at phase phi (in radians). 
%   n>0 for acoustic, n<0 for optic mode
%   m>0 for longitudinal, m<0 for transverse

if nargin<3, phi=pi/2; end;
if nargin<2; m=-2; end;
if nargin<1; n=-16; end;

if m*n==0 return; end;
if n<0
    n = -n;
    ao = -0.55;
else
    ao = 1; 
end;
if m<0
    m = -m;
    a = [0 0 4];
    d = [3.5 0 0];
else
    a = [1 0 0]; 
    d = [3.5 0 0];
end;

lstick = [0 0 8];
Connect(-lstick,lstick,1,0.8*[1 1 1]);
hold on;
oldpos = [0 0 0];
for i=1:n+1
    phase = m*pi*i/(n+1);
    if mod(i,2)==0
        col = [0.1 0.1 1];
        pos = i*d+a*sin(phase)*sin(phi);
        r = 1;
    else
        col = [1 0.1 0.1];
        pos = i*d+ao*a*sin(phase)*sin(phi);
        r = 1.15;
    end;
    if i<n+1, Atom(pos,r,col); end;
    Spring(oldpos, pos, 1.5, 0.4, 0.2);
    oldpos = pos;
end;
Connect(pos-lstick,pos+lstick,1,0.8*[1 1 1]);

view(-60,2); 
axis equal; axis off; camlight; lighting gouraud;
hold off;
